DEFAULT_FALSE_PROP = 0
UNPROCESSABLE_ENTITY = 422

DNY_HIGH = 'dny_high'
DNY_LOW = 'dny_low'
ALERT_HIGH_1 = 'alert_high_1'
ALERT_HIGH_2 = 'alert_high_2'
ALERT_LOW_1 = 'alert_low_1'
ALERT_LOW_2 = 'alert_low_2'

PW_STABILITY_LIMIT_VALUE = 10
PW_STABILITY_FACTOR = 0.0

HISTORY_DATA_INTERVAL = 10 * 60
TIME_WINDOW_INTERVAL = 20

INCREASE_TENDENCY_FACTOR = 0.9
DECREASE_TENDENCY_FACTOR = 0.9

